==> qiho-center-api-2.11.34-20231214.025614-11-sources.jar: com/qiho/center/api/dto/page/PageComponentDetailDto.java <==
package com.qiho.center.api.dto.page;

import com.qiho.center.api.dto.BaseDto;
import com.qiho.center.api.enums.page.PageStatusEnum;
import com.qiho.center.api.enums.page.PageTypeEnum;

import java.util.Date;
import java.util.List;

/**组件化页面详细信息
 * @author chensong
 * @create 2018-08-02
 */
public class PageComponentDetailDto extends BaseDto{

    /**
     * 页面id
     */
    private Long id;

    /**
     * 页面名称
     */
    private String pageName;

    /**
     * 页面类型 {@link PageTypeEnum#value}
     */
    private Integer pageType;

    /**
     * 页面地址
     */
    private String pageUrl;

    /**
     * 页面效果图地址
     */
    private String pageImg;

    /**
     * 页面状态 {@link PageStatusEnum#value}
     */
    private Integer pageStatus;

    /**
     * 页面md5
     */
    private String pageMd5;

    /**
     * 页面其他信息
     */
    private String pageInfo;

    /**
     * 页面最后操作人
     */
    private String operatorName;

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /**
     * 页面表单策略
     */
    private List<PageFormStrategyDto> strategyTypeList;

    /** 组件列表信息 */
    private List<PageComponentDto> componentList;

    private String tagNums;

    /**
     * 自动打标
     */
    private String autoPromoteTag;

    /**
     * 媒体备案信息自定义
     */
    private String landpageMedia;

    public String getLandpageMedia() {
        return landpageMedia;
    }

    public void setLandpageMedia(String landpageMedia) {
        this.landpageMedia = landpageMedia;
    }

    public String getAutoPromoteTag() {
        return autoPromoteTag;
    }

    public void setAutoPromoteTag(String autoPromoteTag) {
        this.autoPromoteTag = autoPromoteTag;
    }

    public String getTagNums() {
        return tagNums;
    }

    public void setTagNums(String tagNums) {
        this.tagNums = tagNums;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getPageName() {
        return pageName;
    }

    public void setPageName(String pageName) {
        this.pageName = pageName;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public String getPageUrl() {
        return pageUrl;
    }

    public void setPageUrl(String pageUrl) {
        this.pageUrl = pageUrl;
    }

    public String getPageImg() {
        return pageImg;
    }

    public void setPageImg(String pageImg) {
        this.pageImg = pageImg;
    }

    public Integer getPageStatus() {
        return pageStatus;
    }

    public void setPageStatus(Integer pageStatus) {
        this.pageStatus = pageStatus;
    }

    public String getPageMd5() {
        return pageMd5;
    }

    public void setPageMd5(String pageMd5) {
        this.pageMd5 = pageMd5;
    }

    public String getPageInfo() {
        return pageInfo;
    }

    public void setPageInfo(String pageInfo) {
        this.pageInfo = pageInfo;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public List<PageComponentDto> getComponentList() {
        return componentList;
    }

    public void setComponentList(List<PageComponentDto> componentList) {
        this.componentList = componentList;
    }

    public List<PageFormStrategyDto> getStrategyTypeList() {
        return strategyTypeList;
    }

    public void setStrategyTypeList(List<PageFormStrategyDto> strategyTypeList) {
        this.strategyTypeList = strategyTypeList;
    }
}

==> qiho-center-api-2.11.65-sources.jar: com/qiho/center/api/dto/page/PageComponentDetailDto.java <==
package com.qiho.center.api.dto.page;

import com.qiho.center.api.dto.BaseDto;
import com.qiho.center.api.enums.page.PageStatusEnum;
import com.qiho.center.api.enums.page.PageTypeEnum;

import java.util.Date;
import java.util.List;

/**组件化页面详细信息
 * @author chensong
 * @create 2018-08-02
 */
public class PageComponentDetailDto extends BaseDto{

    /**
     * 页面id
     */
    private Long id;

    /**
     * 页面名称
     */
    private String pageName;

    /**
     * 页面类型 {@link PageTypeEnum#value}
     */
    private Integer pageType;

    /**
     * 页面地址
     */
    private String pageUrl;

    /**
     * 页面效果图地址
     */
    private String pageImg;

    /**
     * 页面状态 {@link PageStatusEnum#value}
     */
    private Integer pageStatus;

    /**
     * 页面md5
     */
    private String pageMd5;

    /**
     * 页面其他信息
     */
    private String pageInfo;

    /**
     * 页面最后操作人
     */
    private String operatorName;

    /** 创建时间 */
    private Date gmtCreate;

    /** 修改时间 */
    private Date gmtModified;

    /**
     * 页面表单策略
     */
    private List<PageFormStrategyDto> strategyTypeList;

    /** 组件列表信息 */
    private List<PageComponentDto> componentList;

    private String tagNums;

    /**
     * 自动打标
     */
    private String autoPromoteTag;

    /**
     * 媒体备案信息自定义
     */
    private String landpageMedia;

    /**
     * 背景色
     */
    private String backgroundColor;

    public String getBackgroundColor() {
        return backgroundColor;
    }

    public void setBackgroundColor(String backgroundColor) {
        this.backgroundColor = backgroundColor;
    }

    public String getLandpageMedia() {
        return landpageMedia;
    }

    public void setLandpageMedia(String landpageMedia) {
        this.landpageMedia = landpageMedia;
    }

    public String getAutoPromoteTag() {
        return autoPromoteTag;
    }

    public void setAutoPromoteTag(String autoPromoteTag) {
        this.autoPromoteTag = autoPromoteTag;
    }

    public String getTagNums() {
        return tagNums;
    }

    public void setTagNums(String tagNums) {
        this.tagNums = tagNums;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getPageName() {
        return pageName;
    }

    public void setPageName(String pageName) {
        this.pageName = pageName;
    }

    public Integer getPageType() {
        return pageType;
    }

    public void setPageType(Integer pageType) {
        this.pageType = pageType;
    }

    public String getPageUrl() {
        return pageUrl;
    }

    public void setPageUrl(String pageUrl) {
        this.pageUrl = pageUrl;
    }

    public String getPageImg() {
        return pageImg;
    }

    public void setPageImg(String pageImg) {
        this.pageImg = pageImg;
    }

    public Integer getPageStatus() {
        return pageStatus;
    }

    public void setPageStatus(Integer pageStatus) {
        this.pageStatus = pageStatus;
    }

    public String getPageMd5() {
        return pageMd5;
    }

    public void setPageMd5(String pageMd5) {
        this.pageMd5 = pageMd5;
    }

    public String getPageInfo() {
        return pageInfo;
    }

    public void setPageInfo(String pageInfo) {
        this.pageInfo = pageInfo;
    }

    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public List<PageComponentDto> getComponentList() {
        return componentList;
    }

    public void setComponentList(List<PageComponentDto> componentList) {
        this.componentList = componentList;
    }

    public List<PageFormStrategyDto> getStrategyTypeList() {
        return strategyTypeList;
    }

    public void setStrategyTypeList(List<PageFormStrategyDto> strategyTypeList) {
        this.strategyTypeList = strategyTypeList;
    }
}
